Learn R Programming

RAPIDR (version 0.1.1)

BinBam.gcCorrect: BinBam.gcCorrect

Description

Given a list of bam files, this function writes the output to a text file after binning and doing gc Correction NOTE: Not for production use

Usage

BinBam.gcCorrect(bam.file, index = bam.file, gcContent = NULL)

Arguments

bam.file
name of bamfile
index
index of bam file
gcContent
name of the gccontent data