BinBam.gcCorrect: BinBam.gcCorrect
Description
Given a list of bam files, this function writes the output
to a text file after binning and doing gc Correction NOTE:
Not for production useUsage
BinBam.gcCorrect(bam.file, index = bam.file, gcContent = NULL)
Arguments
gcContent
name of the gccontent data